## AISCOT 6.1.0

- Added support for DOT's SeaVision.
- Dropped support for Python 3.6

## AISCOT 6.0.0

- New for 2024.
- Updates for AryaSea (fka SeaTAK).

## AISCOT 5.3.0

Added COT_ICON support.

## AISCOT 5.2.0

1) Fixed GitHub workflows (revert to not-latest ubuntu, add py 3.10).
2) Reformatted & Cleaned-up README.
3) Updated copyright year.
4) Renamed 'AISHUB_URL' to 'FEED_URL'.
5) Added instructions for updating SHIP & MIB databases.
6) Removed broad function import in module's init.
7) Refactored AIS specific functions into ais_functions.
8) Added tests, tests, tests! Now at almost 100% for functions.

## AISCOT 5.1.0

Added XML Declaration to output CoT XML.